%bcond_without doc

Summary:	The official C++ client API for PostgreSQL
Name:		libpqxx
Version:	7.3.0
Release:	%mkrel 1
License:	GPLv2+
Group:		Development/Databases
Url:		http://pqxx.org/
Source0:	https://github.com/jtv/libpqxx/archive/%version/%name-%version.tar.gz
BuildRequires:	cmake
BuildRequires:	pkgconfig(libpq)
%if %{with doc}
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	xmlto
%endif

%description
This library works on top of the C-level API library, libpq. You will need
libpq in order to use libpqxx.

The first thing you're likely to notice in programming with libpqxx is that
unlike other libraries, it revolves entirely around transactions. Transactions
are a central concept in database management systems, but they are widely
underappreciated among application developers. Another well-known open source
database system, MySQL, never even got around to implementing them at all in
their own engine, relying on a third-party replacement engine (now owned by
Oracle) to provide this functionality instead.

%package devel
Summary:        Headers for developing programs that will use %{name}
Group:          Development/C++
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains the headers that programmers will need to develop
applications which will use %{name}.

%if %{with doc}
%package doc
Summary:        Developer documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description doc
Developer documentation for %{name}.
%endif

%prep
%setup -q
%autopatch -p1

# fix spurious permissions
chmod -x COPYING

%build
%cmake \
        %if %{with doc}
        -DBUILD_DOC=ON
        %endif
%cmake_build

%install
%cmake_install

%files
%doc AUTHORS NEWS README.md VERSION
%license COPYING
%_libdir/libpqxx-*.so

%files devel
%doc README-UPGRADE
%_includedir/pqxx/
%_libdir/libpqxx.so
%_libdir/pkgconfig/libpqxx.pc
%_libdir/cmake/libpqxx/

%if %{with doc}
%files doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/accessing-results.md
%{_docdir}/%{name}/datatypes.md
%{_docdir}/%{name}/escaping.md
%{_docdir}/%{name}/getting-started.md
%{_docdir}/%{name}/mainpage.md
%{_docdir}/%{name}/performance.md
%{_docdir}/%{name}/prepared-statement.md
%{_docdir}/%{name}/streams.md
%{_docdir}/%{name}/thread-safety.md
%{_docdir}/%{name}/html
%endif


%changelog
* Fri Dec 18 2020 joequant <joequant> 7.3.0-1.mga8
+ Revision: 1660871
- update to 7.3.0

* Sun May 10 2020 daviddavid <daviddavid> 7.0.7-1.mga8
+ Revision: 1582458
- new version: 7.0.7

* Fri May 01 2020 daviddavid <daviddavid> 7.0.6-1.mga8
+ Revision: 1577464
- new version: 7.0.6

* Tue Mar 24 2020 daviddavid <daviddavid> 7.0.5-1.mga8
+ Revision: 1559182
- new version: 7.0.5

* Fri Feb 21 2020 daviddavid <daviddavid> 7.0.2-1.mga8
+ Revision: 1548825
- new version: 7.0.2

* Thu Feb 20 2020 umeabot <umeabot> 7.0.1-2.mga8
+ Revision: 1547385
- Mageia 8 Mass Rebuild

* Sun Feb 09 2020 daviddavid <daviddavid> 7.0.1-1.mga8
+ Revision: 1488116
- new version: 7.0.1
- switch to cmake build system
- compile docs

* Sat Feb 01 2020 daviddavid <daviddavid> 6.4.5-1.mga8
+ Revision: 1486223
- new version: 6.4.5
- fix owner of include dir
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 4.0.1-10.mga7
+ Revision: 1299097
- Mageia 7 Mass Rebuild

* Sat Jun 09 2018 wally <wally> 4.0.1-9.mga7
+ Revision: 1235760
- fix build on aarch64

* Sun May 06 2018 daviddavid <daviddavid> 4.0.1-8.mga7
+ Revision: 1226751
- add patch to fix linker issue during configure

* Thu Feb 11 2016 umeabot <umeabot> 4.0.1-7.mga6
+ Revision: 955617
- Mageia 6 Mass Rebuild

* Wed Aug 26 2015 fwang <fwang> 4.0.1-6.mga6
+ Revision: 869475
- rebuild for gcc5

* Tue Nov 25 2014 cjw <cjw> 4.0.1-5.mga5
+ Revision: 798949
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 4.0.1-4.mga5
+ Revision: 738916
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.0.1-3.mga5
+ Revision: 681717
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 4.0.1-2.mga4
+ Revision: 531331
- Mageia 4 Mass Rebuild

* Sun Aug 04 2013 fwang <fwang> 4.0.1-1.mga4
+ Revision: 463114
- new version 4.0.1

* Sat Jan 12 2013 umeabot <umeabot> 4.0-2.mga3
+ Revision: 357988
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 04 2011 fwang <fwang> 4.0-1.mga2
+ Revision: 175969
- new version 4.0

* Fri Feb 11 2011 ahmad <ahmad> 3.1-3.mga1
+ Revision: 50400
- drop old/unneeded scriptlets
- don't ship .la
- imported package libpqxx

